pub struct CheckerActor { /* private fields */ }Trait Implementations
Sourceimpl Actor for CheckerActor
impl Actor for CheckerActor
Sourcetype Msg = CheckerMessage
type Msg = CheckerMessage
The type of messages sent and received by the actor. Read more
Sourcetype Timer = CheckerTimer
type Timer = CheckerTimer
The type for tagging timers. Read more
Sourcetype State = CheckerState
type State = CheckerState
The type of state maintained by the actor. Read more
Sourcefn on_start(&self, id: Id, o: &mut Out<Self>) -> Self::State
fn on_start(&self, id: Id, o: &mut Out<Self>) -> Self::State
Indicates the initial state and commands.
Sourcefn on_msg(
&self,
_id: Id,
state: &mut Cow<'_, Self::State>,
_src: Id,
msg: Self::Msg,
o: &mut Out<Self>,
)
fn on_msg( &self, _id: Id, state: &mut Cow<'_, Self::State>, _src: Id, msg: Self::Msg, o: &mut Out<Self>, )
Indicates the next state and commands when a message is received. See
Out::send.Sourcefn on_timeout(
&self,
_id: Id,
state: &mut Cow<'_, Self::State>,
timer: &Self::Timer,
o: &mut Out<Self>,
)
fn on_timeout( &self, _id: Id, state: &mut Cow<'_, Self::State>, timer: &Self::Timer, o: &mut Out<Self>, )
Indicates the next state and commands when a timeout is encountered. See
Out::set_timer.fn name(&self) -> String
Sourceimpl Clone for CheckerActor
impl Clone for CheckerActor
Sourcefn clone(&self) -> CheckerActor
fn clone(&self) -> CheckerActor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckerActor
impl Debug for CheckerActor
Sourceimpl Hash for CheckerActor
impl Hash for CheckerActor
Sourceimpl PartialEq for CheckerActor
impl PartialEq for CheckerActor
impl Eq for CheckerActor
impl StructuralPartialEq for CheckerActor